==> ocstore25_4_23.zip: OcStore/Prgm/data/map/CS_puu_restaurant.lua <==
function E0090()
    MNA()CMU("CS_Vivi")FAI(0)
end
function E0091()
    MNA()CMU("CS_Vivi")FAI(1)
end
function E0092()
    MNA()CMU("CS_Vivi")FAI(2)
end
function E0093()
    MNA()CMU("CS_Vivi")FAI(3)
end
function E0094()
    MNA()CMU("CS_Vivi")FAI(4)
end

function Door_GoSeaPath()
    PRI()MM0()SOU("CS_011_door")ANP("Door_GoSeaPath",0,1)FAO(1)TRA("CS_seapath","E0093",36,10)
end

function GoSoapCastle()
    PRI()FAO(3)TRA("CS_soapcastle","E0091",47,11,0,6)
end

function SomeWhereTalking()
    KEY()
    HMC()
    FAI(0)
    WAI(32)
    for i=0,5,1 do
        SOU("CS_023_thud")
        WAI(16)
    end
    WAI(64)
    SOU("CS_056_splash")
    WAI(32)
    SOU("CS_056_splash")
    WAI(64)
    for i=0,5,1 do
        SOU("CS_023_thud")
        WAI(16)
    end
    FAO(0)
    SMC()
    TRA("CS_seapath","LoadPos",17,10)
end

function Arowana()
    PRI()
    if(WET()) then
        MS4("鱼还在水中活蹦乱跳的，")NOD()
        CAT("没法捕获。")NOD()
    else
        KEY()
        MS4("是没见过的好大鱼！")NOD()
        CAT("\n这应该是我这辈子钓的最大一条了！")NOD()CLR()CLO()
        AMC("show_sweat",GLR(PLY()),PLY())
        WAI(128)
        MS4("\n好重啊！")NOD()CLO()
        WAI(32)
        FAO(0)
        AMC("hide_sweat",GLR(PLY()),PLY())
        TRA("CS_seapath","ArowanaWake",0,0)
    end
end

function IronheadDeadAni()
    KEY()
    CMU("CS_Vivi")
    SNP("CS_soapwalker_animate",20,26,1,"mainLayer","Tala1")
    SNP("CS_redhead_animate",27,32,0,"mainLayer","Ironhead1")
    ANP("Tala1","look_down")
    ANP("Ironhead1","slow")
    FAI(3)
    WAI(32)
    SNP("CS_puu_animate",7,26,1,"mainLayer","Puu1")
    WAI(32)
    ANP("Tala1","look_normal",0)
    ANP("Tala1","normal",0)
    WAI(32)
    FAC("soapwalker_normal")MS3("\n兄弟你来啦~")NOD()CLO()
    ANP("Puu1","walk",1)
    WAI(4*16)
    ANP("Tala1","look_down")
    WAI(4*16)
    ANP("Puu1","normal")
    WAI(16)
    FAC("puu_normal")MS3("\n发生什么事了...")NOD()CLR()
    FAC("soapwalker_normal")CAT("我在千钧一发时赶上了，")NOD()
    CAT("\n算是用铁头成功把大王骗过去了。")NOD()CLR()
    CAT("\n只不过...")NOD()CLR()
    FAC("puu_normal")CAT("\n只不过？")NOD()CLO()
    ANP("Ironhead1","die")
    WAI(32)
    ANP("Tala1","normal",1)
    WAI(128)
    FAC("soapwalker_normal")MS3("\n他翻肚皮了呢...")NOD()CLR()
    FAC("puu_normal")CAT("\n嘿，你怎么把它给弄死了。")NOD()CLR()
    FAC("soapwalker_normal")CAT("没办法呀，")NOD()
    CAT("\n时间紧迫我只能把它放在传送器上烤了...")NOD()CLR()
    CAT("如果不这么做，")NOD()
    CAT("\n现在翻肚皮的就是你了...")NOD()CLR()
    FAC("puu_normal")CAT("\n我知道啦...")NOD()CLR()
    ANP("Tala1","normal",0)
    FAC("soapwalker_normal")CAT("\n那铁头现在该怎么处理。")NOD()CLR()
    FAC("puu_normal")CAT("\n只能先找个地方把它埋了吧...")NOD()CLR()
    FAC("soapwalker_normal")CAT("你不想把他红烧一下尝尝什么味嘛？")NOD()
    CAT("\n虽然它现在已经是“红烧”过的了。")NOD()CLR()
    ANP("Puu1","normal",0)
    FAC("puu_normal")CAT("你真变态，")NOD()
    CAT("\n你那么想吃就交给你处理了。")NOD()CLR()
    FAC("soapwalker_normal")CAT("\n开一下玩笑啦...")NOD()CLO()
    FAO(0)
    TRA("CS_soapcastle_jail","PreparingToExplore",8,12)
end

==> ocstore25_7_23.zip: OcStore/Prgm/data/map/CS_puu_restaurant.lua <==
function E0090()
    MNA()CMU("CS_Vivi")FAI(0)
end
function E0091()
    MNA()CMU("CS_Vivi")FAI(1)
end
function E0092()
    MNA()CMU("CS_Vivi")FAI(2)
end
function E0093()
    MNA()CMU("CS_Vivi")FAI(3)
end
function E0094()
    MNA()CMU("CS_Vivi")FAI(4)
end

function Door_GoSeaPath()
    if(FLJ("HeroBack")) then
        PRI()
        MS4("门的那边被岩石堵死了")
        CAT("\n无法打开...")NOD()
    else
        PRI()MM0()SOU("CS_011_door")ANP("Door_GoSeaPath",0,1)FAO(1)TRA("CS_seapath","E0093",36,10)
    end
end

function GoSoapCastle()
    PRI()FAO(3)TRA("CS_soapcastle","E0091",47,11,0,6)
end

function SomeWhereTalking()
    KEY()
    HMC()
    FAI(0)
    WAI(32)
    for i=0,5,1 do
        SOU("CS_023_thud")
        WAI(16)
    end
    WAI(64)
    SOU("CS_056_splash")
    WAI(32)
    SOU("CS_056_splash")
    WAI(64)
    for i=0,5,1 do
        SOU("CS_023_thud")
        WAI(16)
    end
    FAO(0)
    SMC()
    TRA("CS_seapath","LoadPos",17,10)
end

function Arowana()
    PRI()
    if(WET()) then
        MS4("鱼还在水中活蹦乱跳的，")NOD()
        CAT("没法捕获。")NOD()
    else
        KEY()
        MS4("从没见过这么大条的鱼！")NOD()
        CAT("\n这应该是我这辈子钓的最大一条了！")NOD()CLR()CLO()
        AMC("show_sweat",GLR(PLY()),PLY())
        WAI(128)
        MS4("\n好重啊！")NOD()CLO()
        WAI(32)
        FAO(0)
        AMC("hide_sweat",GLR(PLY()),PLY())
        TRA("CS_seapath","ArowanaWake",0,0)
    end
end

function IronheadDeadAni()
    KEY()
    CMU("CS_Vivi")
    SNP("CS_soapwalker_animate",20,26,1,"mainLayer","Tala1")
    SNP("CS_redhead_animate",27,32,0,"mainLayer","Ironhead1")
    ANP("Tala1","look_down")
    ANP("Ironhead1","slow")
    FAI(3)
    WAI(32)
    SNP("CS_puu_animate",7,26,1,"mainLayer","Puu1")
    WAI(32)
    ANP("Tala1","look_normal",0)
    ANP("Tala1","normal",0)
    WAI(32)
    FAC("soapwalker_normal")MS3("\n兄弟你来啦~")NOD()CLO()
    ANP("Puu1","walk",1)
    WAI(4*16)
    ANP("Tala1","look_down")
    WAI(4*16)
    ANP("Puu1","normal")
    WAI(16)
    FAC("puu_normal")MS3("\n发生什么事了...")NOD()CLR()
    FAC("soapwalker_normal")CAT("我在千钧一发时赶上了，")NOD()
    CAT("\n算是用铁头成功把大王骗过去了。")NOD()CLR()
    CAT("\n只不过...")NOD()CLR()
    FAC("puu_normal")CAT("\n只不过？")NOD()CLO()
    ANP("Ironhead1","die")
    WAI(32)
    ANP("Tala1","normal",1)
    WAI(128)
    FAC("soapwalker_normal")MS3("\n他翻肚皮了呢...")NOD()CLR()
    FAC("puu_normal")CAT("\n嘿，你怎么把它给弄死了。")NOD()CLR()
    FAC("soapwalker_normal")CAT("没办法呀，")NOD()
    CAT("\n时间紧迫我只能把它放在传送器上烤了...")NOD()CLR()
    CAT("如果不这么做，")NOD()
    CAT("\n现在翻肚皮的就是你了...")NOD()CLR()
    FAC("puu_normal")CAT("\n我知道啦...")NOD()CLR()
    ANP("Tala1","normal",0)
    FAC("soapwalker_normal")CAT("\n那铁头现在该怎么处理。")NOD()CLR()
    FAC("puu_normal")CAT("\n只能先找个地方把它埋了吧...")NOD()CLR()
    FAC("soapwalker_normal")CAT("你不想把他红烧一下尝尝什么味嘛？")NOD()
    CAT("\n虽然它现在已经是“红烧”过的了。")NOD()CLR()
    ANP("Puu1","normal",0)
    FAC("puu_normal")CAT("你真变态，")NOD()
    CAT("\n你那么想吃就交给你处理了。")NOD()CLR()
    FAC("soapwalker_normal")CAT("\n开一下玩笑啦...")NOD()CLO()
    FAO(0)
    TRA("CS_soapcastle_jail","PreparingToExplore",8,12)
end
